Crate uv_cache

Crate uv_cache 

Structs

ArchiveId
A unique identifier for an archive (unzipped wheel) in the cache.
Cache
The main cache abstraction.
CacheEntry
A CacheEntry which may or may not exist yet.
CacheShard
A subdirectory within the cache.
CachedByTimestamp
Removal
A removal operation with statistics on the number of files and directories removed.

Enums

CacheBucket
The different kinds of data in the cache are stored in different bucket, which in our case are subdirectories of the cache root.
Error
Error locking a cache entry or shard
Freshness
Refresh
A refresh policy for cache entries.
RemovalMode
The storage accounting used when removing cache entries.
WheelCache
Cache wheels and their metadata, both from remote wheels and built from source distributions.

Constants

ARCHIVE_VERSION
The version of the archive bucket.

Traits

CleanReporter