ArchiveId

Struct ArchiveId 

pub struct ArchiveId(/* private fields */);
A unique identifier for an archive (unzipped wheel) in the cache.

Note: for compatibility with the existing archive-v0 bucket, this is a newtype around a String instead of a newtype around uv_fastid::Id. In the future, we may want to bump to archive-v1 and switch to using uv_fastid::Id directly.

Implementations

Source

impl ArchiveId

pub fn from_digest(digest: String) -> Self

Use a path-safe digest as the complete archive identifier.

This does not generate or hash an identifier. Callers must ensure that the digest uniquely identifies the persisted directory contents.